window.Gleam.initSearch([{"doc":"globlin","title":"globlin","content":"# globlin\n\n[![Package Version](https://img.shields.io/hexpm/v/globlin)](https://hex.pm/packages/globlin)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/globlin/)\n\nThis package brings file globbing to Gleam. A `Pattern` is created by compiling the glob pattern string into the equivalent regex internally. This pattern can then be compared against other strings to find matching paths.\n\nNote: This library doesn&#39;t include methods to directly query the file system so that it can be used in the browser where that isn&#39;t available. If you&#39;re looking for file system globbing, check out the [globlin_fs](https://hexdocs.pm/globlin_fs/index.html) package.\n\nNote 2: This library only currently supports Unix file paths. That means it should work on Linux, macOS and BSD.\n\n## Add Dependency\n\n```sh\ngleam add globlin\n```\n\n## Pattern Syntax\n\nThere are seven special matching patterns supported by this package. They should be familiar to anyone who has used similar packages before.\n\n### Question Mark `?`\n\nThis matches any single character except the slash `/`.\n\n### Star `*`\n\nThis matches zero or more characters except the slash `/`.\n\n### Globstar `**`\n\nThis matches zero or more directories. It must be surrounded by the end of the string or slash `/`.\n\nExamples:\n- Isolated: `**`\n- Prefix: `**/tail`\n- Infix: `head/**/tail`\n- Postfix: `**`\n\nNote: When found at the end of the pattern, it matches all directories and files.\n\n### Inclusive Char Set `[abc]`\n\nThis matches any character in the set.\n\n### Exclusive Char Set `[!abc]`\n\nThis matches any character not in the set when the exclamation point `!` follows the opening square bracket.\n\n### Inclusive Range `[a-z]`\n\nThis matches any character from start to finish.\n\n### Exclusive Range `[!a-z]`\n\nThis matches any character not included in a range.\n\n## Option Flags\n\nThere are two option flags available to change the behavior of matching. They are both turned off by default when using the `new_pattern` method.\n\n### `ignore_case`\n\nThis changes all matches to be case insensitive.\n\n### `match_dotfiles`\n\nAllow wildcards like `?`, `*` and `**` to match dotfiles.\n\n## Example\n\n```gleam\nimport gleam/io\nimport gleam/list\nimport globlin\n\npub fn main() {\n  let files = [\n    &quot;.gitignore&quot;, &quot;gleam.toml&quot;, &quot;LICENCE&quot;, &quot;manifest.toml&quot;, &quot;README.md&quot;,\n    &quot;src/globlin.gleam&quot;, &quot;test/globlin_test.gleam&quot;,\n  ]\n\n  let assert Ok(pattern) = globlin.new_pattern(&quot;**/*.gleam&quot;)\n\n  files\n  |&gt; list.filter(keeping: globlin.match_pattern(pattern:, path: _))\n  |&gt; list.each(io.println)\n  // src/globlin.gleam\n  // test/globlin_test.gleam\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/globlin&gt;.\n\n## Development\n\n```sh\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"globlin","title":"Pattern","content":"pub opaque type Pattern\n Each path pattern holds a compiled regex and options.\n\nSynonyms:\ngloblin.Pattern\ngloblin Pattern","url":"globlin.html#Pattern"},{"doc":"globlin","title":"PatternError","content":"pub type PatternError {\n  AbsolutePatternFromDirError\n  InvalidGlobStarError\n  MissingClosingBracketError\n}\n\nAbsolutePatternFromDirError\n   - The pattern must NOT start with a slash if compiled with a directory prefix.\n\nInvalidGlobStarError\n   - The globstar (&quot;**&quot;) must always appear between the end of a string and/or a slash.\n\nMissingClosingBracketError\n   - A char set or range was opened but never closed.\n\nSynonyms:\ngloblin.PatternError\ngloblin PatternError","url":"globlin.html#PatternError"},{"doc":"globlin","title":"PatternOptions","content":"pub type PatternOptions {\n  PatternOptions(ignore_case: Bool, match_dotfiles: Bool)\n}\n Options that can be provided to the `new_pattern_with` method.\n\n - ignore_case: All matching is case insensitive (Default: False)\n - match_dotfiles: Match dotfiles when using wildcards (Default: False)\nPatternOptions(ignore_case: Bool, match_dotfiles: Bool)\n\n\nSynonyms:\ngloblin.PatternOptions\ngloblin PatternOptions","url":"globlin.html#PatternOptions"},{"doc":"globlin","title":"match_pattern","content":"pub fn match_pattern(\n  pattern pattern: Pattern,\n  path path: String,\n) -&gt; Bool\n Compare a `Pattern` against a path to see if they match.\nSynonyms:\ngloblin.match_pattern\ngloblin match_pattern","url":"globlin.html#match_pattern"},{"doc":"globlin","title":"new_pattern","content":"pub fn new_pattern(\n  pattern: String,\n) -&gt; Result(Pattern, PatternError)\n Compile a `Pattern` from a pattern.\nSynonyms:\ngloblin.new_pattern\ngloblin new_pattern","url":"globlin.html#new_pattern"},{"doc":"globlin","title":"new_pattern_with","content":"pub fn new_pattern_with(\n  pattern: String,\n  from directory: String,\n  with options: PatternOptions,\n) -&gt; Result(Pattern, PatternError)\n Compile a `Pattern` from a directory, pattern and options.\n The directory is escaped and prefixed before the pattern.\nSynonyms:\ngloblin.new_pattern_with\ngloblin new_pattern_with","url":"globlin.html#new_pattern_with"},{"doc":"globlin","title":"globlin","content":"","url":"globlin.html"}]);